===================
 ``zope.password``
===================

.. image:: https://img.shields.io/pypi/v/zope.password.svg
        :target: https://pypi.python.org/pypi/zope.password/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.password.svg
        :target: https://pypi.org/project/zope.password/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/zope.password.png?branch=master
        :target: https://travis-ci.org/zopefoundation/zope.password

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.password/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.password?branch=master

.. image:: https://readthedocs.org/projects/zopepassword/badge/?version=latest
        :target: https://zopepassword.readthedocs.io/en/latest/
        :alt: Documentation Status

This package provides a password manager mechanism. Password manager
is an utility object that can encode and check encoded
passwords.

Documentation is hosted at https://zopepassword.readthedocs.io/
